@@ -13,14 +13,14 @@ Created on Wed Nov 13 02:27:08 2013
 
 import datetime, re, sys
 
-'''The Redis instance.'''
+''' The Redis instance.'''
 R = None
 
-'''The main separator for components of a DB key.'''
+''' The main separator for components of a DB key.'''
 SEP = ':'
 
 def redis2python(red, cast=None):
-    '''Converts ``red`` to Python strings.
+    ''' Converts ``red`` to Python strings.
 
         Parameters:
 
@@ -47,11 +47,11 @@ def redis2python(red, cast=None):
     return cast(red) if cast else red
     #.redis2python()
 
-'''An empty class. It can be used to hold arbitrary variables.'''
+''' An empty class. It can be used to hold arbitrary variables.'''
 class Empty: pass
 
 class Model:
-    '''The base model.
+    ''' The base model.
 
     To make it work, you can provide:
 
@@ -103,17 +103,19 @@ class Model:
 
     _AUTO_ID = True
 
-    '''Default set size that Redis supports. You can change this for your needs.
-    However this value does *not* affect indexes (which use sorted set).'''
+    ''' Default set size that Redis supports. You can change this for your
+        needs. However this value does *not* affect indexes (which use sorted
+        set).'''
     _SET_SIZE = 2**32 - 1
 
-    '''Add all fields that you want them to be indexed to this list. If you do,
-    you might consider overriding function ``_score()`` to support your values.
+    ''' Add all fields' *names* that you want them to be indexed to this list.
+        If you do, you might consider overriding function ``_score()`` to
+        support your values.
     '''
     _INDEXES = []
 
-    '''This is *not* maximum length of strings that you can store. Redis allows
-    up to 512 MiB.
+    ''' This is *not* maximum length of strings that you can store (Redis allows
+        up to 512 MiB).
 
         This is the maximum length of strings that can be *calculated* their
         score. If a string length is larger than this value, then only the first
@@ -125,10 +127,10 @@ class Model:
     '''
     _MAX_STR_LEN = 99
 
-    '''Convenient value for maximum string's score.'''
+    ''' Convenient value for maximum string's score.'''
     _MAX_STR_SCORE = sys.float_info.max
 
-    '''Sets to ``True`` to compares strings with case. Default is ``False``.'''
+    ''' Sets to ``True`` to compares strings with case. Default is ``False``.'''
     _STR_CASE_SENSITIVE = False
 
     ### CONSTANTS
@@ -148,14 +150,14 @@ class Model:
 
     @classmethod
     def _serie_name(cls):
-        '''Returns the serie name of this object in DB.
+        ''' Returns the serie name of this object in DB.
         '''
         return cls.__qualname__
 
     @classmethod
     def _uid(cls, inc=True):
-        '''Returns the current unique ID of the model. If ``inc`` is ``True``,
-        increases the ID by ``1`` and returns new value.
+        ''' Returns the current unique ID of the model. If ``inc`` is ``True``,
+            increases the ID by ``1`` and returns new value.
         '''
 
         _ = SEP.join([cls._serie_name(), cls._S_ID])
@@ -164,9 +166,10 @@ class Model:
 
     @classmethod
     def _redis2python(cls, name, key, obj):
-        '''Determines Python type of class' variable ``name``, then reads data
-        from Redis at ``key``, converts the data read to corresponding Python
-        type and assigns the value to variable ``name`` of object ``obj``.
+        ''' Determines Python type of class' variable ``name``, then reads data
+            from Redis at ``key``, converts the data read to corresponding
+            Python type and assigns the value to variable ``name`` of object
+            ``obj``.
         '''
 
         attr = getattr(cls, name)
@@ -226,7 +229,7 @@ class Model:
     @classmethod
     def query(cls, func=None, *names, id_gt=None, id_lt=None, limit=None,
               order=None):
-        '''Queries.
+        ''' Queries.
 
         Parameters:
 
@@ -349,8 +352,8 @@ class Model:
 
     @classmethod
     def _add_id(cls, _id):
-        '''Adds an ID to ID set. This does nothing if ``_AUTO_ID`` is ``False``,
-        or ``_id < 0``.
+        ''' Adds an ID to ID set. This does nothing if ``_AUTO_ID`` is
+            ``False``, or ``_id < 0``.
         '''
 
         if _id < 0: return
@@ -367,8 +370,8 @@ class Model:
 
     @classmethod
     def _remove_id(cls, _id):
-        '''Remove an ID from ID set. This does nothing if ``_AUTO_ID`` is
-        ``False``, or ``_id < 0``.'''
+        ''' Remove an ID from ID set. This does nothing if ``_AUTO_ID`` is
+            ``False``, or ``_id < 0``.'''
 
         if _id < 0: return
 
@@ -384,7 +387,7 @@ class Model:
 
     @classmethod
     def count(cls):
-        '''Counts total item of current model.
+        ''' Counts total item of current model.
         '''
 
         result = i = 0
@@ -400,10 +403,10 @@ class Model:
 
     @classmethod
     def _score(cls, obj):
-        '''Override this function to "score" your values. By default, this
-        function supports some numeric objects such as ``int``, ``float``,
-        ``complex``, ``bool``; ``datetime``, ``date`` and ``time`` in module
-        ``datetime``.
+        ''' Override this function to "score" your values. By default, this
+            function supports some numeric objects such as ``int``, ``float``,
+            ``complex``, ``bool``; ``datetime``, ``date`` and ``time`` in module
+            ``datetime``.
 
         For ``str``s, this function turns them to lower case, then calculates
         their value by summing up all characters.
@@ -451,7 +454,7 @@ class Model:
         #._score()
 
     def __init__(self, __strict=True, **args):
-        '''Creates new instance. ``args`` is a list of key-value pairs.
+        ''' Creates new instance. ``args`` is a list of key-value pairs.
 
         Parameters:
 
@@ -494,7 +497,7 @@ class Model:
         #.__init__()
 
     def put(self):
-        '''Put this item into DB.
+        ''' Put this item into DB.
         '''
 
         pipe = R.pipeline()
@@ -517,7 +520,7 @@ class Model:
             value = allvars[name]
 
             if self._id >= 0 and hasattr(self.__class__, name) and \
-                getattr(self.__class__, name) in self.__class__._INDEXES:
+                name in self.__class__._INDEXES:
                 key_index = key_indexes + name
                 if value != None:
                     pipe.zadd(key_index, self.__class__._score(value), self._id)
@@ -585,7 +588,7 @@ class Model:
         #.put()
 
     def delete(self):
-        '''Deletes this item. Returns ``True`` if OK, ``None`` otherwise.
+        ''' Deletes this item. Returns ``True`` if OK, ``None`` otherwise.
         '''
 
         keys = []
@@ -601,7 +604,7 @@ class Model:
 
             if self._id >= 0:
                 _ = SEP.join([self.__class__._serie_name(), str(self._id), name])
-                if keys_indexes != None and attr in self.__class__._INDEXES:
+                if keys_indexes != None and name in self.__class__._INDEXES:
                     keys_indexes.append(name)
             else:
                 _ = SEP.join([self.__class__._serie_name(), name])
